@@ -50,7 +50,7 @@ BaptistaPike_exact_conditional_CI_2x2 <- function(n, alpha = 0.05) {
 
   # Output
   printresults <- function() {
-    my_sprintf_cat(
+    cat_sprintf(
       "Baptista-Pike exact conditional CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)",
       estimate, 100 * (1 - alpha), L, U
     )
