@@ -44,7 +44,7 @@ BonettPrice_hybrid_Wilson_score_CI_paired_2x2 <- function(n, alpha = 0.05) {
 
   # Output
   printresults <- function() {
-    my_sprintf_cat(
+    cat_sprintf(
       "The Bonett-Price hybrid Wilson score CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)",
       estimate, 100 * (1 - alpha), L, U
     )
