@@ -43,9 +43,9 @@ Bonferroni_type_CIs_paired_cxc <- function(n, alpha = 0.05) {
 
   # Output
   printresults <- function() {
-    my_sprintf_cat("Bonferroni-type simultaneous intervals\n")
+    cat_sprintf("Bonferroni-type simultaneous intervals\n")
     for (i in 1:c) {
-      my_sprintf_cat(
+      cat_sprintf(
         "  pi_%g+ vs pi_ + %g: delta = %7.4f (%7.4f to %7.4f)\n",
         i, i, deltahat[i], L[i], U[i]
       )
