@@ -30,7 +30,7 @@ Exact_binomial_test_1x2 <- function(X, n, pi0) {
 
   # Output
   printresults <- function() {
-    my_sprintf_cat("The exact binomial test: P = %7.5f", P)
+    cat_sprintf("The exact binomial test: P = %7.5f", P)
   }
   return(contingencytables_result(list(P = P), printresults))
 }
