@@ -51,8 +51,8 @@ Score_test_and_CI_marginal_mean_scores_paired_cxc <- function(n, a = seq_len(nro
   P <- 2 * (1 - pnorm(abs(Z_score), 0, 1))
 
   printresults <- function() {
-    my_sprintf_cat("The score test: P = %7.5f, Z = %6.3f\n", P, Z_score)
-    my_sprintf_cat("The score CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)", estimate, 100 * (1 - alpha), L, U)
+    cat_sprintf("The score test: P = %7.5f, Z = %6.3f\n", P, Z_score)
+    cat_sprintf("The score CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)", estimate, 100 * (1 - alpha), L, U)
   }
 
   return(
