@@ -1,20 +1,23 @@
 #' @title The Wald confidence interval for the difference between probabilities
-#' @description The Wald confidence interval for the difference between probabilities with Yates's continuity correction. Described in Chapter 4 "The 2x2 Table"
+#' @description The Wald confidence interval for the difference between
+#' probabilities with Yates's continuity correction. Described in Chapter 4
+#' "The 2x2 Table"
 #' @param n the observed counts (a 2x2 matrix)
 #' @param alpha the nominal level, e.g. 0.05 for 95% CIs
-#' @param printresults display results (FALSE = no, TRUE = yes)
 #' @examples
 #' # An RCT of high vs standard dose of epinephrine (Perondi et al., 2004)
-#' n <- matrix(c(7, 27, 1, 33), nrow = 2, byrow = TRUE)
-#' Wald_CI_CC_2x2(n)
+#' Wald_CI_CC_2x2(perondi_2004)
 #'
 #' # The association between CHRNA4 genotype and XFS (Ritland et al., 2007)
-#' n <- matrix(c(0, 16, 15, 57), nrow = 2, byrow = TRUE)
-#' Wald_CI_CC_2x2(n)
+#' Wald_CI_CC_2x2(ritland_2007)
 #'
 #' @export
-#' @return A data frame containing lower, upper and point estimates of the statistic
-Wald_CI_CC_2x2 <- function(n, alpha = 0.05, printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+Wald_CI_CC_2x2 <- function(n, alpha = 0.05) {
+  validateArguments(mget(ls()))
+
   n1p <- n[1, 1] + n[1, 2]
   n2p <- n[2, 1] + n[2, 2]
 
@@ -42,13 +45,16 @@ Wald_CI_CC_2x2 <- function(n, alpha = 0.05, printresults = TRUE) {
   L <- max(-1, L)
   U <- min(U, 1)
 
-  if (printresults) {
-    print(sprintf(
-      "The Wald CI with continuity correction: estimate = %6.4f (%g%% CI %6.4f to %6.4f)",
+  printresults <- function() {
+    sprintf(
+      paste(
+        "The Wald CI with continuity correction: estimate =",
+        "%6.4f (%g%% CI %6.4f to %6.4f)"
+      ),
       estimate, 100 * (1 - alpha), L, U
-    ), quote = FALSE)
+    )
   }
 
-  res <- data.frame(lower = L, upper = U, estimate = estimate)
-  invisible(res)
+  res <- list(lower = L, upper = U, estimate = estimate)
+  return(contingencytables_result(res, printresults))
 }
