@@ -37,39 +37,34 @@ calc_Pvalue_5x2 <- function(...) {
   UseMethod("calc_Pvalue_5x2", method)
 }
 
+dispatch_lookup <- data.frame(
+  "fn" = c(
+    "Koopman_asymptotic_score_CI_2x2",
+    "Mee_asymptotic_score_CI_2x2",
+    "MiettinenNurminen_asymptotic_score_CI_difference_2x2",
+    "MiettinenNurminen_asymptotic_score_CI_OR_2x2",
+    "MiettinenNurminen_asymptotic_score_CI_ratio_2x2",
+    "Uncorrected_asymptotic_score_CI_2x2",
+    "CochranArmitage_exact_cond_midP_tests_rx2",
+    "Exact_cond_midP_linear_rank_tests_2xc",
+    "Exact_cond_midP_unspecific_ordering_rx2"
+  ),
+  "cls" = c(
+    "Koopman", "Mee", "Miettinen_diff", "Miettinen_OR", "Miettinen_ratio",
+    "Uncorrected", "CochranArmitage", "ExactCond_linear",
+    "ExactCond_unspecific"
+  )
+)
+
 #' @author Waldir Leoncio
 convertFunName2Method <- function() {
-  callstack <- as.list(sys.calls())
+  callstack <- gsub(x = as.character(sys.calls()), "\\(.+$", "") # func names
   findInCallstack <- function(regex) {
-    length_function_name <- length(callstack[grepl(regex, callstack)])
-    return(length_function_name > 0)
+    return(!is.na(match(regex, callstack)))
   }
-  if (findInCallstack("^Koopman_asymptotic_score_CI")) {
-    cls <- "Koopman"
-  } else if (findInCallstack("^Mee_asymptotic_score_CI")) {
-    cls <- "Mee"
-  } else if (findInCallstack("^MiettinenNurminen_asymptotic_score_CI_diff")) {
-    cls <- "Miettinen_diff"
-  } else if (findInCallstack("^MiettinenNurminen_asymptotic_score_CI_OR")) {
-    cls <- "Miettinen_OR"
-  } else if (findInCallstack("^MiettinenNurminen_asymptotic_score_CI_rat")) {
-    cls <- "Miettinen_ratio"
-  } else if (findInCallstack("^Uncorrected_asymptotic_score_CI_2x2")) {
-    cls <- "Uncorrected"
-  } else if (findInCallstack("^CochranArmitage")) {
-    cls <- "CochranArmitage"
-  } else if (findInCallstack("^Exact_cond_midP_unspecific_ordering_rx2")) {
-    cls <- "ExactCond"
-  } else if (findInCallstack("Exact_cond_midP_linear_rank_tests_2xc")) {
-    cls <- "ExactCont_linear"
-  } else if (findInCallstack("Exact_cond_midP_unspecific_ordering_rx2")) {
-    cls <- "ExactCond_unspecific"
-  } else {
-    stop("Unrecognized parent function")
-  }
-  fun_name <- cls
-  class(fun_name) <- cls
-  return(fun_name)
+  cls_match <- dispatch_lookup[match(callstack, dispatch_lookup[["fn"]]), "cls"]
+  cls <- cls_match[!is.na(cls_match)]
+  return(structure(cls, class = cls))
 }
 
 # ======================================================== #
@@ -335,87 +330,6 @@ ML_estimates.Uncorrected <- function(theta0, n11, n21, n1p, n2p, ...) {
   return(res)
 }
 
-# ======================================================== #
-# Methods for Exact_cond_midP_unspecific_ordering_rx2      #
-# ======================================================== #
-
-# Calculate the probability of table x
-# (multiple hypergeometric distribution)
-
-calc_prob.ExactCond <- function(x, r, N_choose_np1, nip_choose_xi1, ...) {
-  f <- 1
-  for (i in 1:r) {
-    f <- f * nip_choose_xi1[i, x[i] + 1]
-  }
-  f <- f / N_choose_np1
-  return(f)
-}
-
-# Brute force calculations of the two-sided exact P-value and the mid-P value
-# This function assumes r=4 rows
-
-calc_Pvalue_4x2.ExactCond <- function(Tobs, nip, np1, npj, N, N_choose_np1, nip_choose_xi1, direction, statistic, ...) {
-  P <- 0
-  point_prob <- 0
-  for (x1 in 0:min(nip[1], np1)) {
-    for (x2 in 0:min(nip[2], np1 - x1)) {
-      for (x3 in 0:min(nip[3], np1 - x1 - x2)) {
-        x4 <- np1 - x1 - x2 - x3
-        if (x4 > nip[4]) {
-          next
-        }
-        x <- rbind(c(x1, nip[1] - x1), c(x2, nip[2] - x2), c(x3, nip[3] - x3), c(x4, nip[4] - x4))
-        T0 <- test_statistic(x, 4, nip, npj, N, direction, statistic)
-        f <- calc_prob.ExactCond(x[, 1], 4, N_choose_np1, nip_choose_xi1)
-        if (T0 == Tobs) {
-          point_prob <- point_prob + f
-        } else if (T0 > Tobs) {
-          P <- P + f
-        }
-      }
-    }
-  }
-  midP <- P + 0.5 * point_prob
-  P <- P + point_prob
-  res <- list(P = P, midP = midP)
-  return(res)
-}
-
-# Brute force calculations of the two-sided exact P-value and the mid-P value
-# This function assumes r=5 rows
-
-calc_Pvalue_5x2.ExactCond <- function(Tobs, nip, np1, npj, N, N_choose_np1, nip_choose_xi1, direction, statistic, ...) {
-  P <- 0
-  point_prob <- 0
-  for (x1 in 0:min(nip[1], np1)) {
-    for (x2 in 0:min(nip[2], np1 - x1)) {
-      for (x3 in 0:min(nip[3], np1 - x1 - x2)) {
-        for (x4 in 0:min(nip[4], np1 - x1 - x2 - x3)) {
-          x5 <- np1 - x1 - x2 - x3 - x4
-          if (x5 > nip[5]) {
-            next
-          }
-          x <- rbind(
-            c(x1, nip[1] - x1), c(x2, nip[2] - x2), c(x3, nip[3] - x3),
-            c(x4, nip[4] - x4), c(x5, nip[5] - x5)
-          )
-          T0 <- test_statistic(x, 5, nip, npj, N, direction, statistic)
-          f <- calc_prob.ExactCond(x[, 1], 5, N_choose_np1, nip_choose_xi1)
-          if (T0 == Tobs) {
-            point_prob <- point_prob + f
-          } else if (T0 > Tobs) {
-            P <- P + f
-          }
-        }
-      }
-    }
-  }
-  midP <- P + 0.5 * point_prob
-  P <- P + point_prob
-  res <- list(P = P, midP = midP)
-  return(res)
-}
-
 # ======================================================== #
 # Methods for Cochran-Armitage                             #
 # ======================================================== #
@@ -506,7 +420,7 @@ calc_Pvalue_5x2.CochranArmitage <- function(Tobs, nip, np1, N_choose_np1, nip_ch
 # Brute force calculations of the one-sided P-values. Return the smallest one.
 # This function assumes c=3 columns
 
-calc_Pvalue_2x3.ExactCont_linear <- function(Tobs, nip, npj, N_choose_n1p, npj_choose_x1j, b) {
+calc_Pvalue_2x3.ExactCond_linear <- function(Tobs, nip, npj, N_choose_n1p, npj_choose_x1j, b) {
   left_sided_P <- 0
   right_sided_P <- 0
   point_prob <- 0
@@ -535,7 +449,7 @@ calc_Pvalue_2x3.ExactCont_linear <- function(Tobs, nip, npj, N_choose_n1p, npj_c
 # Brute force calculations of the one-sided P-values. Return the smallest one.
 # This function assumes c=4 columns
 
-calc_Pvalue_2x4.ExactCont_linear <- function(Tobs, nip, npj, N_choose_n1p, npj_choose_x1j, b) {
+calc_Pvalue_2x4.ExactCond_linear <- function(Tobs, nip, npj, N_choose_n1p, npj_choose_x1j, b) {
   left_sided_P <- 0
   right_sided_P <- 0
   point_prob <- 0
@@ -548,7 +462,7 @@ calc_Pvalue_2x4.ExactCont_linear <- function(Tobs, nip, npj, N_choose_n1p, npj_c
         }
         x <- c(x1, x2, x3, x4)
         T0 <- linear_rank_test_statistic(x, b)
-        f <- calc_prob.ExactCont_linear(x, 4, N_choose_n1p, npj_choose_x1j)
+        f <- calc_prob.ExactCond_linear(x, 4, N_choose_n1p, npj_choose_x1j)
         if (T0 == Tobs) {
           point_prob <- point_prob + f
         } else if (T0 < Tobs) {
@@ -566,7 +480,7 @@ calc_Pvalue_2x4.ExactCont_linear <- function(Tobs, nip, npj, N_choose_n1p, npj_c
 # Calculate the probability of table x
 # (multiple hypergeometric distribution)
 
-calc_prob.ExactCont_linear <- function(x, c, N_choose_n1p, npj_choose_x1j, ...) {
+calc_prob.ExactCond_linear <- function(x, c, N_choose_n1p, npj_choose_x1j, ...) {
   f <- 1
   for (j in 1:c) {
     f <- f * npj_choose_x1j[j, x[j] + 1]
